@@ -174,8 +174,8 @@ Color* colorAdd_color(Color* color)
       color_storageArray = g_list_append(color_storageArray, (gpointer)color);
       DBG_fprintf(stderr, "Visu Tools : adding a new color at %p (%d).\n",
 		  (gpointer)color_storageArray, g_list_length(color_storageArray));
-      g_signal_emit (visu, VISU_GET_CLASS(visu)->colorNewAvailable_signal_id,
-		     0 , (gpointer)color, NULL);
+      g_signal_emit(VISU_INSTANCE, VISU_GET_CLASS(VISU_INSTANCE)->colorNewAvailable_signal_id,
+		    0 , (gpointer)color, NULL);
     }
   return color;
 }
@@ -200,8 +200,8 @@ Color* colorAdd_floatRGBA(float rgba[4], int *position)
     *position = g_list_length(color_storageArray);
   DBG_fprintf(stderr, "Visu Tools : adding a new color at %p (%d).\n",
 	      (gpointer)color_storageArray, g_list_length(color_storageArray));
-  g_signal_emit (visu, VISU_GET_CLASS (visu)->colorNewAvailable_signal_id,
-		 0 , (gpointer)color, NULL);
+  g_signal_emit(VISU_INSTANCE, VISU_GET_CLASS(VISU_INSTANCE)->colorNewAvailable_signal_id,
+		0 , (gpointer)color, NULL);
   return color;
 }
 Color* colorAdd_intRGBA(int rgba[4])
@@ -226,8 +226,8 @@ Color* colorAdd_intRGBA(int rgba[4])
   color_storageArray = g_list_append(color_storageArray, (gpointer)color);
   DBG_fprintf(stderr, "Visu Tools : adding a new color at %p (%d).\n",
 	      (gpointer)color_storageArray, g_list_length(color_storageArray));
-  g_signal_emit (visu, VISU_GET_CLASS (visu)->colorNewAvailable_signal_id,
-		 0 , (gpointer)color, NULL);
+  g_signal_emit(VISU_INSTANCE, VISU_GET_CLASS(VISU_INSTANCE)->colorNewAvailable_signal_id,
+		0 , (gpointer)color, NULL);
   return color;
 }
 Color* colorGet_lastStored()
