@@ -52,7 +52,8 @@
  *
  * Domain used to parse config files.
  */
-GQuark CONFIG_FILE_ERROR;
+#define CONFIG_FILE_ERROR configFileGet_quark()
+GQuark configFileGet_quark();
 /**
  * toolConfigFileError:
  * @CONFIG_FILE_ERROR_EMPTY_LINE: error when reading the file, found an empty line,
@@ -82,6 +83,8 @@ typedef enum
     CONFIG_FILE_ERROR_MARKUP
   } toolConfigFileError;
 
+void configFileInit();
+
 /**
  * configFileRead_floatFromTokens:
  * @tokens: array of tokens resulting from a call to g_strsplit() with " " as separator ;
