@@ -89,6 +89,18 @@ struct FileFormatProperty_struct
 };
 void fileFormatFree_property(FileFormatProperty* propValue);
 
+static GQuark quark;
+
+GQuark fileFormatGet_quark()
+{
+  return quark;
+}
+
+void fileFormatInit()
+{
+  quark = g_quark_from_static_string("toolFileFormat");
+}
+
 FileFormat* fileFormatNew(gchar* descr, gchar** patterns)
 {
   int nbCharacterMax = 45;
