@@ -47,6 +47,15 @@
 #include <visu_tools.h>
 #include <math.h>
 
+/**
+ * SECTION:toolMatrix
+ * @short_description: Defines basic handlings on matrix.
+ *
+ * <para>Some very basic linear algebra are redefined here. It also
+ * gives access to coordinates conversion, essentially between
+ * cartesian and spherical.</para>
+ */
+
 gboolean matrix_reducePrimitiveVectors(float reduced[6], double full[3][3])
 {
   float X[3];
@@ -205,16 +214,12 @@ void matrix_productVector(float vectRes[3], float mat[3][3], float vect[3])
     }
 }
 
-#ifndef PI
-#define PI 3.1415926
-#endif
-
 #ifndef RAD2DEG
-#define RAD2DEG(x) ((180./PI)*x)
+#define RAD2DEG(x) (57.29577951308232311 * x)
 #endif
 
 #ifndef DEG2RAD
-#define DEG2RAD(x) ((PI/180.)*x)
+#define DEG2RAD(x) (0.01745329251994329509 * x)
 #endif
 
 /* s[0] = pho, s[1] = theta, s[2] = phi
@@ -239,22 +244,22 @@ void matrix_cartesianToSpherical(float *spherical, float *cartesian)
   rho = sqrt(c[0]*c[0] + c[1]*c[1] + c[2]*c[2]);
 
   if(c[0] == 0 && c[1] == 0)
-    theta = (c[2] > 0) ? 0 : PI;
+    theta = (c[2] > 0) ? 0 : G_PI;
   else 
     theta = acos(c[2]/rho);
 
   if(c[0] != 0)
     {
-      phi = atan(c[1]/c[0]) + PI*((c[0] < 0) ? 1 : 0);
+      phi = atan(c[1]/c[0]) + G_PI*((c[0] < 0) ? 1 : 0);
     }
   else
     {
       if(c[1] == 0) /* facultatif*/
 	phi = 0;    /* facultatif*/
       else if(c[1] > 0)
-	phi = PI/2;
+	phi = G_PI_2;
       else
-	phi = -PI/2;
+	phi = -G_PI_2;
     }
 
   s[0] = rho;
