@@ -188,7 +188,7 @@ gboolean writeDataToCairoSurface(cairo_surface_t *cairo_surf, VisuData *dataObj,
   visuDataIter_new(dataObj, &iter);
   view = visuDataGet_openGLView(dataObj);
   method = getRenderingMethodInUse();
-  lights = lightEnvironnementGet_lightList(currentLights);
+  lights = lightEnvironnementGet_lightList(openGLGet_currentLights());
   g_return_val_if_fail(lights, FALSE);
   light = (Light*)lights->data;
 
