@@ -166,14 +166,14 @@ OpenGLExtension* initExtensionAxes()
   axesLineWidth   = RESOURCE_AXES_LINE_DEFAULT;
   axesLineStipple = RESOURCE_AXES_STIPPLE_DEFAULT;
 
-  g_signal_connect(G_OBJECT(visu), "dataReadyForRendering",
+  g_signal_connect(VISU_INSTANCE, "dataReadyForRendering",
 		   G_CALLBACK(onDataReadySignal), (gpointer)0);
-  g_signal_connect(G_OBJECT(visu), "dataNew",
+  g_signal_connect(VISU_INSTANCE, "dataNew",
 		   G_CALLBACK(onDataNewSignal), (gpointer)0);
 
-  g_signal_connect(G_OBJECT(visu), "SpinAxes",
+  g_signal_connect(VISU_INSTANCE, "SpinAxes",
  		   G_CALLBACK(onAxesConfigChange), (gpointer)0);
-  g_signal_connect(G_OBJECT(visu), "resourcesLoaded",
+  g_signal_connect(VISU_INSTANCE, "resourcesLoaded",
  		   G_CALLBACK(rebuildAxesOnResourcesLoaded), (gpointer)0);
 
 
@@ -540,7 +540,7 @@ void axesDraw(VisuData *dataObj)
   glLoadIdentity();
   glFrustum(mini, maxi, mini, maxi, near, far);
   glMatrixMode(GL_MODELVIEW);
-  if(pointerOnRenderingSpinMethod == getRenderingMethodInUse())
+  if(getRenderingMethodInUse() == renderingSpinGet_static())
     {
       float phi_prime_zero, phi_a, theta_a;
 
@@ -572,7 +572,7 @@ void axesDraw(VisuData *dataObj)
 
       drawAxes(1.5*length, w, h, axesLineWidth, "back", TRUE);
     }
-  else if(pointerOnRenderingAtomicMethod == getRenderingMethodInUse())
+  else if(getRenderingMethodInUse() == renderingAtomicGet_static())
     {
       glViewport(xx, yy, w, h);
 
