@@ -146,9 +146,9 @@ OpenGLExtension* initExtensionBox()
 				     description, listBox, rebuildBox);
   OpenGLExtensionSet_priority(extensionBox, OPENGL_EXTENSION_PRIORITY_LOW);
 
-  g_signal_connect(G_OBJECT(visu), "dataReadyForRendering",
+  g_signal_connect(VISU_INSTANCE, "dataReadyForRendering",
 		   G_CALLBACK(rebuildBoxOnDataReady), (gpointer)0);
-  g_signal_connect(G_OBJECT(visu), "resourcesLoaded",
+  g_signal_connect(VISU_INSTANCE, "resourcesLoaded",
  		   G_CALLBACK(rebuildBoxOnResources), (gpointer)0);
 
   resourceEntry = visuConfigFileAdd_entry(VISU_CONFIGFILE_RESOURCE,
