@@ -44,18 +44,43 @@
 #include <gtk/gtksignal.h>
 #include <gtk/gtkdialog.h>
 
-#include "gtk_dumpDialogWidget.h"
+#include <visu_gtk.h>
 #include <gtk_main.h>
+#include "gtk_dumpDialogWidget.h"
 #include <opengl.h>
 
-static void dumpDialog_class_init          (DumpDialogClass *klass);
-static void dumpDialog_init                (DumpDialog *dumpDialog);
-static void dumpDialog_destroy             (GtkObject *object);
+/**
+ * SECTION:dumpdialog
+ * @short_description: Defines a widget to export into different file
+ * formats.
+ * 
+ * <para>This widget is based on the #GtkFileChooser in the save
+ * mode. It proposes the user to choose a file to save to. In
+ * addition, it automatically build a list of filters, corresponding
+ * to the available export routines in V_Sim. By default, the filter
+ * is set on 'auto', which means that the filter method is selected
+ * with the file extension. The dialog also has a progress bar.</para>
+ *
+ * <para>This widget is also a dialog, and should be used with
+ * gtk_dialog_run(). After the response GTK_RESPONSE_ACCEPT has been
+ * recieved, one can grep the selected filename with
+ * dumpDialogGet_fileName(). The dialog does not call the exporting
+ * routine by itself, the calling method should take care of
+ * that. When doing it, the filechoosing part should be made
+ * insensitive, using dumpDialogStart() and the progress bar should be
+ * updated accordingly (get it with
+ * dumpDialogGet_progressBar()).</para>
+ *
+ * <para>The user interface propose also to change the size  (see
+ * dumpDialogGet_heightValue() and dumpDialogGet_widthValue()) and if
+ * some options are associated to a file format, these options are
+ * displayed.</para>
+ */
 
+static void dumpDialog_dispose (GObject *obj);
+static void dumpDialog_finalize(GObject *obj);
 
-GtkDialogClass *parent_class;
-
-struct DumpDialog_struct
+struct _DumpDialog
 {
   GtkDialog dialog;
 
@@ -63,7 +88,7 @@ struct DumpDialog_struct
 
   GtkWidget *hBoxOptions;
   GtkWidget *comboType;
-  DumpType *selectedFileFormat;
+  DumpType  *selectedFileFormat;
   GtkWidget *expanderFileFormat;
   GtkWidget *checkFileExtension;
   GtkWidget *spinWidth, *spinHeight;
@@ -71,59 +96,43 @@ struct DumpDialog_struct
   GtkWidget *progressBar;
   GtkWidget *cancelButton;
 
-  gchar *dumpFileName;
+  gchar     *dumpFileName;
 
-  VisuData *dataObj;
+  VisuData  *dataObj;
+
+  /* Memory gestion. */
+  gboolean dispose_has_run;
 };
 
-struct DumpDialogClass_struct
+struct _DumpDialogClass
 {
   GtkDialogClass parent_class;
 
+  guint width, height;
+  gchar *current_dir;
+
   void (*dumpDialog) (DumpDialog *dump);
 };
 
 /* Local callbacks */
+static void onWidthHeightChanged(GtkSpinButton *spin, gpointer data);
 static void onSpinPropertyChange(GtkSpinButton *spin, gpointer data);
 static void onCheckPropertyChange(GtkToggleButton *toggle, gpointer data);
 static void onComboFileFormatChange(GtkComboBox *combo, gpointer data);
 static void onDumpDialogResponse(GtkDialog *dialog, gint id, gpointer *data);
 
-
-GType dumpDialog_get_type(void)
-{
-  static GType dumpDialog_type = 0;
-
-  if (!dumpDialog_type)
-    {
-      static const GTypeInfo dumpDialog_info =
-      {
-        sizeof (DumpDialogClass),
-        NULL, /* base_init */
-        NULL, /* base_finalize */
-        (GClassInitFunc) dumpDialog_class_init,
-        NULL, /* class_finalize */
-        NULL, /* class_data */
-        sizeof (DumpDialog),
-        0,
-        (GInstanceInitFunc) dumpDialog_init,
-        NULL
-      };
-      dumpDialog_type = g_type_register_static (GTK_TYPE_DIALOG, "DumpDialog",
-						   &dumpDialog_info, 0);
-      DBG_fprintf(stderr, "Gtk DumpDialog : creating the type DumpDialog %p.\n",
-		  (gpointer)dumpDialog_type);
-    }
-
-  return dumpDialog_type;
-}
+G_DEFINE_TYPE(DumpDialog, dumpDialog, GTK_TYPE_DIALOG)
 
 static void dumpDialog_class_init(DumpDialogClass *klass)
 {
   DBG_fprintf(stderr, "Gtk DumpDialog : creating the class of the widget.\n");
 
-  parent_class = g_type_class_peek_parent(klass);
-  GTK_OBJECT_CLASS(klass)->destroy = dumpDialog_destroy;
+  klass->width  = 0;
+  klass->height = 0;
+  klass->current_dir = (gchar*)0;
+
+  G_OBJECT_CLASS(klass)->dispose = dumpDialog_dispose;
+  G_OBJECT_CLASS(klass)->finalize = dumpDialog_finalize;
 }
 
 static void dumpDialog_init(DumpDialog *dumpDialog)
@@ -139,31 +148,44 @@ static void dumpDialog_init(DumpDialog *dumpDialog)
 		   G_CALLBACK(onDumpDialogResponse), (gpointer)dumpDialog);
 }
 
-static void dumpDialog_destroy(GtkObject *object)
+static void dumpDialog_dispose(GObject *obj)
+{
+  DBG_fprintf(stderr, "Gtk DumpDialog: dispose object %p.\n", (gpointer)obj);
+
+  if (DUMP_DIALOG(obj)->dispose_has_run)
+    return;
+
+  DUMP_DIALOG(obj)->dispose_has_run = TRUE;
+  /* Chain up to the parent class */
+  G_OBJECT_CLASS(dumpDialog_parent_class)->dispose(obj);
+}
+static void dumpDialog_finalize(GObject *obj)
 {
   DumpDialog *dialog;
-  gchar *directory;
 
-  DBG_fprintf(stderr, "Gtk DumpDialog : destroy widget %p.\n", (gpointer)object);
-  dialog = DUMP_DIALOG(object);
+  g_return_if_fail(obj);
+
+  DBG_fprintf(stderr, "Gtk DumpDialog: finalize object %p.\n", (gpointer)obj);
+
+  dialog = DUMP_DIALOG(obj);
   if (dialog->dumpFileName)
-    {
-      /* Set the last browsed directory. */
-      directory = gtk_file_chooser_get_current_folder
-	(GTK_FILE_CHOOSER(dialog->fileChooser));
-      setLastOpenDirectory((char*)directory);
-      g_free(directory);
-      /* Free the stored filename. */
-      g_free(dialog->dumpFileName);
-    }
-/*   GTK_OBJECT_CLASS(parent_class)->destroy(object); */
+    /* Free the stored filename. */
+    g_free(dialog->dumpFileName);
+
+  /* Chain up to the parent class */
+  G_OBJECT_CLASS(dumpDialog_parent_class)->finalize(obj);
+
+  DBG_fprintf(stderr, "Gtk DumpDialog: freeing ... OK.\n");
 }
 
 
-GtkWidget* dumpDialog_new(VisuData *dataObj)
+GtkWidget* dumpDialog_new(VisuData *dataObj, GtkWindow *parent,
+			  const gchar *suggestedFilename)
 {
   DumpDialog *dumpDialog;
-  gchar *directory, *labelType, *filename;
+  DumpDialogClass *klass;
+  gchar *directory, *labelType;
+  const gchar *filename;
   GList *format;
   GtkWidget *hbox2, *hbox;
   GtkWidget *label;
@@ -179,20 +201,15 @@ GtkWidget* dumpDialog_new(VisuData *dataObj)
   DBG_fprintf(stderr, "Gtk DumpDialog : creating a new DumpDialog object.\n");
 
   dumpDialog = DUMP_DIALOG(g_object_new(dumpDialog_get_type(), NULL));
+  klass = DUMP_DIALOG_CLASS(G_OBJECT_GET_CLASS(dumpDialog));
   gtk_dialog_set_has_separator(GTK_DIALOG(dumpDialog), FALSE);
   /* This is to avoid a bug in gtk 2.4 */
 #if GTK_MINOR_VERSION > 5
   gtk_window_set_modal(GTK_WINDOW(dumpDialog), TRUE);
 #endif
-  gtk_window_set_transient_for(GTK_WINDOW(dumpDialog), GTK_WINDOW(mainWindow));
+  gtk_window_set_transient_for(GTK_WINDOW(dumpDialog), GTK_WINDOW(parent));
   gtk_window_set_position(GTK_WINDOW(dumpDialog), GTK_WIN_POS_CENTER_ON_PARENT);
 
-  dumpDialog->dataObj = dataObj;
-  if (dataObj)
-    filename = (gchar*)visuDataGet_property(dataObj, "dumpDialog_filename");
-  else
-    filename = (gchar*)0;
-
   dumpDialog->cancelButton = gtk_dialog_add_button(GTK_DIALOG(dumpDialog),
 					       GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
   gtk_dialog_add_button(GTK_DIALOG(dumpDialog), GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT);
@@ -200,113 +217,119 @@ GtkWidget* dumpDialog_new(VisuData *dataObj)
 
   /* Create the file chooser part. */
   dumpDialog->fileChooser = gtk_file_chooser_widget_new(GTK_FILE_CHOOSER_ACTION_SAVE);
-  gtk_widget_show(dumpDialog->fileChooser);
-  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dumpDialog)->vbox), dumpDialog->fileChooser, TRUE, TRUE, 2);
+#if GTK_MINOR_VERSION > 7
+  gtk_file_chooser_set_do_overwrite_confirmation
+    (GTK_FILE_CHOOSER(dumpDialog->fileChooser), TRUE);
+#endif
+  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dumpDialog)->vbox),
+		     dumpDialog->fileChooser, TRUE, TRUE, 2);
   gtk_file_chooser_set_select_multiple(GTK_FILE_CHOOSER(dumpDialog->fileChooser),
 				       FALSE);
+  /* We set the suggested filename, either a previous one
+     or the one given. */
+  filename = (const gchar*)0;
+  dumpDialog->dataObj = dataObj;
+  if (dataObj)
+    filename = (const gchar*)visuDataGet_property(dataObj, "dumpDialog_filename");
+  if (!filename)
+    filename = suggestedFilename;
+  if (filename)
+    gtk_file_chooser_set_current_name(GTK_FILE_CHOOSER(dumpDialog->fileChooser),
+				      filename);
 
   /* Create the file options part. */
   dumpDialog->hBoxOptions = gtk_hbox_new(FALSE, 0);
-  gtk_widget_show(dumpDialog->hBoxOptions);
-  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dumpDialog)->vbox),
-		     dumpDialog->hBoxOptions, FALSE, FALSE, 2);
+  gtk_file_chooser_set_extra_widget(GTK_FILE_CHOOSER(dumpDialog->fileChooser),
+				    dumpDialog->hBoxOptions);
 
   vbox = gtk_vbox_new(FALSE, 0);
-  gtk_widget_show(vbox);
   gtk_box_pack_start(GTK_BOX(dumpDialog->hBoxOptions), vbox, TRUE, TRUE, 2);
   hbox = gtk_hbox_new(FALSE, 0);
-  gtk_widget_show(hbox);
   gtk_box_pack_start(GTK_BOX(vbox),
 		     hbox, FALSE, FALSE, 0);
   /* Label to introduce the combobox which allow to choose the format */
   label = gtk_label_new(_("Choose the file format : "));
   gtk_misc_set_alignment(GTK_MISC(label), 0., 0.5);
-  gtk_widget_show(label);
   gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 0);
   dumpDialog->comboType = gtk_combo_box_new_text();
   /* Set the combo entry that let V_Sim detect the desired format through the extension. */
   gtk_combo_box_append_text(GTK_COMBO_BOX(dumpDialog->comboType), _("Autodetect format"));
   gtk_combo_box_set_active(GTK_COMBO_BOX(dumpDialog->comboType), 0);
-  gtk_widget_show(dumpDialog->comboType);
   gtk_box_pack_start(GTK_BOX(hbox), dumpDialog->comboType, FALSE, FALSE, 0);
   /* Add an expander for file format options. */
   dumpDialog->expanderFileFormat = gtk_expander_new(_("File format option:"));
   gtk_widget_set_sensitive(dumpDialog->expanderFileFormat, FALSE);
-  gtk_widget_show(dumpDialog->expanderFileFormat);
   gtk_box_pack_start(GTK_BOX(vbox),
 		     dumpDialog->expanderFileFormat, FALSE, FALSE, 0);
   g_signal_connect(G_OBJECT(dumpDialog->comboType), "changed",
 		   G_CALLBACK(onComboFileFormatChange), (gpointer)dumpDialog);
   /* Add a separator. */
   wd = gtk_vseparator_new();
-  gtk_widget_show(wd);
   gtk_box_pack_start(GTK_BOX(dumpDialog->hBoxOptions),
 		     wd, FALSE, FALSE, 0);
   /* Create common options part. */
   vbox = gtk_vbox_new(FALSE, 0);
-  gtk_widget_show(vbox);
   gtk_box_pack_start(GTK_BOX(dumpDialog->hBoxOptions), vbox, TRUE, TRUE, 2);
   dumpDialog->checkFileExtension = gtk_check_button_new_with_label(_("Add extension"));
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(dumpDialog->checkFileExtension), TRUE);
   gtk_widget_set_sensitive(dumpDialog->checkFileExtension, FALSE);
-  gtk_widget_show(dumpDialog->checkFileExtension);
   gtk_box_pack_start(GTK_BOX(vbox), dumpDialog->checkFileExtension, FALSE, FALSE, 0);
   hbox = gtk_hbox_new(FALSE, 0);
-  gtk_widget_show(hbox);
   gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
   label = gtk_label_new(_("Width: "));
   gtk_misc_set_alignment(GTK_MISC(label), 0., 0.5);
-  gtk_widget_show(label);
   gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 0);
-  dumpDialog->spinWidth = gtk_spin_button_new_with_range(0., 2000., 1.);
-  if (view)
+  dumpDialog->spinWidth = gtk_spin_button_new_with_range(1., 2000., 1.);
+  if (klass->width > 0)
+    gtk_spin_button_set_value(GTK_SPIN_BUTTON(dumpDialog->spinWidth),
+			      (gdouble)klass->width);
+  else if (view)
     gtk_spin_button_set_value(GTK_SPIN_BUTTON(dumpDialog->spinWidth),
 			      (gdouble)view->window->width);
-  gtk_widget_show(dumpDialog->spinWidth);
   gtk_box_pack_start(GTK_BOX(hbox), dumpDialog->spinWidth, FALSE, FALSE, 0);
   label = gtk_label_new(_("px"));
-  gtk_widget_show(label);
   gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
   hbox = gtk_hbox_new(FALSE, 0);
-  gtk_widget_show(hbox);
   gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
   label = gtk_label_new(_("Height: "));
   gtk_misc_set_alignment(GTK_MISC(label), 0., 0.5);
-  gtk_widget_show(label);
   gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 0);
-  dumpDialog->spinHeight = gtk_spin_button_new_with_range(0., 2000., 1.);
-  if (view)
+  dumpDialog->spinHeight = gtk_spin_button_new_with_range(1., 2000., 1.);
+  if (klass->height > 0)
+    gtk_spin_button_set_value(GTK_SPIN_BUTTON(dumpDialog->spinHeight),
+			      (gdouble)klass->height);
+  else if (view)
     gtk_spin_button_set_value(GTK_SPIN_BUTTON(dumpDialog->spinHeight),
 			      (gdouble)view->window->height);
-  gtk_widget_show(dumpDialog->spinHeight);
   gtk_box_pack_start(GTK_BOX(hbox), dumpDialog->spinHeight, FALSE, FALSE, 0);
   label = gtk_label_new(_("px"));
-  gtk_widget_show(label);
   gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
-  
+  g_signal_connect(G_OBJECT(dumpDialog->spinWidth), "value-changed",
+		   G_CALLBACK(onWidthHeightChanged), (gpointer)&klass->width);
+  g_signal_connect(G_OBJECT(dumpDialog->spinHeight), "value-changed",
+		   G_CALLBACK(onWidthHeightChanged), (gpointer)&klass->height);
 
   
   /* Create the progress bar part. */
   hbox2 = gtk_hbox_new(FALSE, 0);
-  gtk_widget_show(hbox2);
   gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dumpDialog)->vbox), hbox2, FALSE, FALSE, 2);
   /* Label to introduce the rogress bar */
   label = gtk_label_new(_("Dump progress : "));
   gtk_misc_set_alignment(GTK_MISC(label), 0., 0.5);
-  gtk_widget_show(label);
   gtk_box_pack_start(GTK_BOX(hbox2), label, FALSE, FALSE, 0);
   dumpDialog->progressBar = gtk_progress_bar_new();
-  gtk_widget_show(dumpDialog->progressBar);
   gtk_box_pack_start(GTK_BOX(hbox2), dumpDialog->progressBar, TRUE, TRUE, 2);
 
   /* Setting default values. */
   gtk_widget_set_name(GTK_WIDGET(dumpDialog), "filesel");
-  directory = getLastOpenDirectory();
-  if (directory)
-    gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(dumpDialog->fileChooser), directory);
-  if (filename)
-    gtk_file_chooser_set_current_name(GTK_FILE_CHOOSER(dumpDialog->fileChooser), filename);
-  format = getAllDumpModules();
+  directory = gtkMainClassGet_lastOpenDirectory();
+  if (klass->current_dir)
+    gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(dumpDialog->fileChooser),
+					klass->current_dir);
+  else if (directory)
+    gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(dumpDialog->fileChooser),
+					directory);
+  format = visuDumpGet_allModules();
   while (format)
     {
       labelType = fileFormatGet_label(((DumpType*)format->data)->fileType);
@@ -315,6 +338,7 @@ GtkWidget* dumpDialog_new(VisuData *dataObj)
       format = g_list_next(format);
     }
 
+  gtk_widget_show_all(GTK_DIALOG(dumpDialog)->vbox);
   return GTK_WIDGET(dumpDialog);
 }
 
@@ -345,7 +369,7 @@ static void onComboFileFormatChange(GtkComboBox *combo, gpointer data)
   if (wd)
     gtk_widget_destroy(wd);
 
-  dumpTypes = getAllDumpModules();
+  dumpTypes = visuDumpGet_allModules();
   formatInt = gtk_combo_box_get_active(combo);
   DBG_fprintf(stderr, "Gtk DumpDialog : On file format change (%d).\n", formatInt);
   /* Select auto file format -> no properties. */
@@ -420,6 +444,7 @@ static void onDumpDialogResponse(GtkDialog *dialog, gint id, gpointer *data)
   gchar *ext, *pattern;
   GList *dumpTypes;
   DumpDialog *dumpDialog;
+  DumpDialogClass *klass;
 
   g_return_if_fail(IS_DUMP_DIALOG(data));
 
@@ -436,7 +461,9 @@ static void onDumpDialogResponse(GtkDialog *dialog, gint id, gpointer *data)
       if (!filename)
 	{
 	  /* Autodetect failed, no format match the given filename */
-	  raiseAlertDialog(_("No filename chosen."));
+	  visuGtkRaise_warning(_("Saving a file"),
+			       _("No filename chosen."),
+			       GTK_WINDOW(dialog));
 	  g_signal_stop_emission_by_name(G_OBJECT(dumpDialog), "response");
 	  return;
 	}
@@ -444,7 +471,7 @@ static void onDumpDialogResponse(GtkDialog *dialog, gint id, gpointer *data)
 
   if (formatInt >= 0)
     {
-      dumpTypes = getAllDumpModules();
+      dumpTypes = visuDumpGet_allModules();
       if (formatInt == 0)
 	/* The automatic format has been selected, we look in the pattern list to
 	   find a matching pattern. */
@@ -456,7 +483,9 @@ static void onDumpDialogResponse(GtkDialog *dialog, gint id, gpointer *data)
       if (!dumpTypes)
 	{
 	  /* Autodetect failed, no format match the given filename */
-	  raiseAlertDialog(_("The filename doesn't match any know format."));
+	  visuGtkRaise_warning(_("Saving a file"),
+			       _("The filename doesn't match any known format."),
+			       GTK_WINDOW(dialog));
 	  g_free(filename);
 	  g_signal_stop_emission_by_name(G_OBJECT(dumpDialog), "response");
 	  return;
@@ -479,16 +508,24 @@ static void onDumpDialogResponse(GtkDialog *dialog, gint id, gpointer *data)
       else
 	dumpDialog->dumpFileName = filename;
       dumpDialog->selectedFileFormat = (DumpType*)dumpTypes->data;
-      /* Put everything except the progress bar insensitive */
-      gtk_widget_set_sensitive(dumpDialog->fileChooser, FALSE);
-      gtk_widget_set_sensitive(dumpDialog->hBoxOptions, FALSE);
       DBG_fprintf(stderr, "Gtk DumpDialog : '%s' file format chosen.\n",
 		  dumpDialog->selectedFileFormat->fileType->description);
       /* Save the filename in a property of the VisuData object. */
       filename = g_path_get_basename(dumpDialog->dumpFileName);
-      visuDataSet_property(dumpDialog->dataObj, "dumpDialog_filename", (gpointer)filename);
+      visuDataSet_propertyWithDestroyFunc(dumpDialog->dataObj, "dumpDialog_filename",
+					  (gpointer)filename, g_free);
+
+      /* Save the dirname in the class. */
+      klass = DUMP_DIALOG_CLASS(G_OBJECT_GET_CLASS(dumpDialog));
+      if (klass->current_dir)
+	g_free(klass->current_dir);
+      klass->current_dir = g_path_get_dirname(dumpDialog->dumpFileName);
     }
 }
+static void onWidthHeightChanged(GtkSpinButton *spin, gpointer data)
+{
+  *(guint*)data = (guint)gtk_spin_button_get_value(spin);
+}
 
 /******************/
 /* Public methods */
@@ -531,3 +568,15 @@ gint dumpDialogGet_heightValue(DumpDialog *dialog)
   g_return_val_if_fail(dialog, 0);
   return (gint)gtk_spin_button_get_value(GTK_SPIN_BUTTON(dialog->spinHeight));
 }
+void dumpDialogStart(DumpDialog *dialog)
+{
+  /* Put everything except the progress bar insensitive */
+  gtk_widget_set_sensitive(dialog->fileChooser, FALSE);
+  gtk_widget_set_sensitive(dialog->hBoxOptions, FALSE);
+}
+void dumpDialogStop(DumpDialog *dialog)
+{
+  /* Put everything except the progress bar sensitive */
+  gtk_widget_set_sensitive(dialog->fileChooser, TRUE);
+  gtk_widget_set_sensitive(dialog->hBoxOptions, TRUE);
+}
