@@ -110,6 +110,7 @@ struct _OrientationChooser
 
   /* Memory gestion. */
   gboolean dispose_has_run;
+  gulong dataReady;
 };
 
 struct _OrientationChooserClass
@@ -195,6 +196,7 @@ static void orientationChooser_finalize(GObject *obj)
 	      (gpointer)obj);
 
   orientationChooser = ORIENTATION_CHOOSER(obj);
+  g_signal_handler_disconnect(VISU_INSTANCE, orientationChooser->dataReady);
 
   /* Chain up to the parent class */
   G_OBJECT_CLASS(orientationChooser_parent_class)->finalize(obj);
@@ -375,8 +377,9 @@ GtkWidget* orientationChooserNew(OrientationChooserKind kind, gboolean liveUpdat
   /* Set other internal values. */
   orientationChooser->kind = kind;
   visuDataChanged(orientationChooser, data);
-  g_signal_connect(VISU_INSTANCE, "dataReadyForRendering",
-		   G_CALLBACK(onDataReadyForRendering), (gpointer)orientationChooser);
+  orientationChooser->dataReady = g_signal_connect
+    (VISU_INSTANCE, "dataReadyForRendering",
+     G_CALLBACK(onDataReadyForRendering), (gpointer)orientationChooser);
 
   return GTK_WIDGET(orientationChooser);
 }
