@@ -77,6 +77,8 @@ static void onTranslationChanged(GtkSpinButton *spin, gpointer data);
 static void onZoomChanged(GtkSpinButton *spin, gpointer data);
 static void onPerspChanged(GtkSpinButton *spin, gpointer data);
 static void gtkObservePick_marks(PickMesure *pickMesure, gpointer data);
+static gboolean onKillWindowEvent(GtkWidget *widget, GdkEvent *event,
+				  gpointer user_data);
 
 /* Local methods. */
 static void setSensitiveActionSensitive(GtkInteractiveActionId id);
@@ -252,13 +254,8 @@ void gtkInteractiveInit_session()
   flagDisableChangePickObserve = FALSE;
 }
 
-static void onCloseButtonClicked(GtkButton *button _U_, gpointer user_data _U_)
+static void stopInteractive()
 {
-  if (!GTK_WIDGET_VISIBLE(observeWindow))
-    return;
-
-  DBG_fprintf(stderr, "Gtk interactive: click on close button.\n");
-
   gtkPick_onClose();
 
   flagDisableChangePickObserve = TRUE;
@@ -268,6 +265,24 @@ static void onCloseButtonClicked(GtkButton *button _U_, gpointer user_data _U_)
   renderingWindowPop_message(RENDERING_WINDOW(currentRenderingWindow));
   renderingWindowUnblock_defaultIneractiveMode(RENDERING_WINDOW(currentRenderingWindow));
 }
+static gboolean onKillWindowEvent(GtkWidget *widget _U_, GdkEvent *event _U_,
+				  gpointer user_data _U_)
+{
+  DBG_fprintf(stderr, "Gtk interactive: window killed.\n");
+
+  stopInteractive();
+
+  return FALSE;
+}
+static void onCloseButtonClicked(GtkButton *button _U_, gpointer user_data _U_)
+{
+  DBG_fprintf(stderr, "Gtk interactive: click on close button.\n");
+
+  if (!GTK_WIDGET_VISIBLE(observeWindow))
+    return;
+
+  stopInteractive();
+}
 
 static void setSensitiveObserve(gboolean value)
 {
@@ -318,6 +333,11 @@ static void connectSignalsObservePick()
   g_signal_connect(VISU_INSTANCE, "dataNew",
 		   G_CALLBACK(onNewData), (gpointer)0);
 
+  g_signal_connect(G_OBJECT(observeWindow), "delete-event",
+		   G_CALLBACK(onKillWindowEvent), (gpointer)0);
+  g_signal_connect(G_OBJECT(observeWindow), "destroy-event",
+		   G_CALLBACK(onKillWindowEvent), (gpointer)0);
+
   wd = lookup_widget(observeWindow, "buttonBackToCommandPanel");
   g_signal_connect(G_OBJECT(wd), "clicked",
 		   G_CALLBACK(onCloseButtonClicked), (gpointer)0);
