@@ -100,6 +100,7 @@ static GtkWidget *treeviewDataNode;
 #define GTK_PICKOBSERVE_UNEDITABLE_NODE "black"
 static GList *selectedRow;
 static gulong selectedRowSignal;
+static gulong comboInfosSignal;
 
 /* Draw data widgets. */
 static GtkWidget *radioDrawNever, *radioDrawSelected, *radioDrawAlways;
@@ -265,8 +266,8 @@ void gtkPickBuild_interface(GtkMain *main)
   gtk_cell_layout_add_attribute(GTK_CELL_LAYOUT(comboDraw), renderer, "markup",
 				COLUMN_COMBO_LABEL);
   gtk_combo_box_set_active(GTK_COMBO_BOX(comboDraw), 0);
-  g_signal_connect(G_OBJECT(comboDraw), "changed",
-		   G_CALLBACK(onComboInfosChanged), (gpointer)0);
+  comboInfosSignal = g_signal_connect(G_OBJECT(comboDraw), "changed",
+				      G_CALLBACK(onComboInfosChanged), (gpointer)0);
   labelPickOut = lookup_widget(main->interactiveDialog, "pickInfo");
   labelPickError = lookup_widget(main->interactiveDialog, "pickComment");
   gtk_widget_set_name(labelPickError, "label_error");
@@ -412,6 +413,9 @@ static void populateComboInfos(VisuData *dataObj)
   DBG_fprintf(stderr, "Gtk Pick: rebuild the data combo list.\n");
 
   n = gtk_combo_box_get_active(GTK_COMBO_BOX(comboDraw));
+  DBG_fprintf(stderr, "Gtk Pick: combo list previously %d.\n", n);
+
+  g_signal_handler_block(G_OBJECT(comboDraw), comboInfosSignal);
 
   gtk_list_store_clear(listComboInfos);
 
@@ -460,6 +464,7 @@ static void populateComboInfos(VisuData *dataObj)
 		   NULL);
       i += 1;
     }
+  g_signal_handler_unblock(G_OBJECT(comboDraw), comboInfosSignal);
   set = (n >= 0 && n < gtk_tree_model_iter_n_children(GTK_TREE_MODEL(listComboInfos),
 						      (GtkTreeIter*)0));
   gtk_combo_box_set_active(GTK_COMBO_BOX(comboDraw), (set)?n:0);
@@ -728,12 +733,17 @@ static void onComboInfosChanged(GtkComboBox *combo _U_, gpointer data _U_)
   dataObj = renderingWindowGet_visuData(window);
   g_return_if_fail(dataObj);
 
-  if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radioDrawNever)))
+  if (gtk_combo_box_get_active(combo) >= 0)
+    {
+      if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radioDrawNever)))
+	return;
+      else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radioDrawSelected)))
+	drawDataOnNode(dataObj, DRAW_SELECTED);
+      else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radioDrawAlways)))
+	drawDataOnNode(dataObj, DRAW_ALWAYS);
+    }
+  else
     drawDataOnNode(dataObj, DRAW_NEVER);
-  else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radioDrawSelected)))
-    drawDataOnNode(dataObj, DRAW_SELECTED);
-  else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radioDrawAlways)))
-    drawDataOnNode(dataObj, DRAW_ALWAYS);
   g_idle_add(visuObjectRedraw, (gpointer)0);
 }
 static void onRadioDrawInfos(GtkToggleButton *togglebutton, gpointer user_data)
