@@ -417,6 +417,7 @@ GtkInfoArea *gtkStatusInfo_createBar(RenderingWindow *window, gint width, gint h
   /* Load button */
   info->loadButton = gtk_button_new();
   gtk_widget_set_sensitive(info->loadButton, FALSE);
+  gtk_button_set_focus_on_click(GTK_BUTTON(info->loadButton), FALSE);
   gtk_tooltips_set_tip (tooltips, info->loadButton,
 			_("Open"), NULL);
   g_signal_connect_swapped(G_OBJECT(info->loadButton), "clicked",
@@ -427,6 +428,7 @@ GtkInfoArea *gtkStatusInfo_createBar(RenderingWindow *window, gint width, gint h
   gtk_box_pack_start(GTK_BOX(hboxHandle), info->loadButton, FALSE, FALSE, 0);
   /* Refresh button */
   wd = gtk_button_new();
+  gtk_button_set_focus_on_click(GTK_BUTTON(wd), FALSE);
   gtk_tooltips_set_tip (tooltips, wd,
 			_("Refresh"), NULL);
   g_signal_connect(G_OBJECT(wd), "clicked",
@@ -437,6 +439,7 @@ GtkInfoArea *gtkStatusInfo_createBar(RenderingWindow *window, gint width, gint h
   gtk_box_pack_start(GTK_BOX(hboxHandle), wd, FALSE, FALSE, 0);
   /* Save button */
   info->dumpButton = gtk_button_new();
+  gtk_button_set_focus_on_click(GTK_BUTTON(info->dumpButton), FALSE);
   gtk_tooltips_set_tip (tooltips, info->dumpButton,
 			_("Export"), NULL);
   g_signal_connect(G_OBJECT(info->dumpButton), "clicked",
@@ -448,6 +451,7 @@ GtkInfoArea *gtkStatusInfo_createBar(RenderingWindow *window, gint width, gint h
   gtk_box_pack_start(GTK_BOX(hboxHandle), info->dumpButton, FALSE, FALSE, 0);
   /* Auto-raise command panel button */
   info->raiseButton = gtk_button_new();
+  gtk_button_set_focus_on_click(GTK_BUTTON(info->raiseButton), FALSE);
   gtk_tooltips_set_tip (tooltips, info->raiseButton,
 			_("Raise the command panel window."), NULL);
   g_signal_connect(G_OBJECT(info->raiseButton), "clicked",
