@@ -332,7 +332,8 @@ static void onLoadResButtonClicked(GtkButton *button _U_, gpointer data)
   g_free(basename);
 
   DBG_fprintf(stderr, "Gtk Save: emitting 'resourcesLoaded' signal.\n");
-  g_signal_emit(visu, VISU_GET_CLASS(visu)->resourcesLoaded_signal_id,
+  g_signal_emit(VISU_INSTANCE,
+		VISU_GET_CLASS(VISU_INSTANCE)->resourcesLoaded_signal_id,
 		0, dataObj, NULL);
   DBG_fprintf(stderr, "Gtk Save: emission done.\n");
 
