@@ -67,13 +67,16 @@ typedef struct OpenGLView_struct OpenGLView;
  * @d_red: a factor for perspective from 1. to inifnity. With one, the nose of
  *         the observer is completly set on the rendered object, and the size
  *         of the observer is neglectible compared to the size of the object.
- * @gr: a private value equal to d_red / (d_red - 1.) ;
  * @theta: the theta angle in spherical coordinates of the position of the observer ;
  * @phi: the phi angle in spherical coordinates of the position of the observer ;
  * @omega: rotation of the observer on itself ;
  * @xs: a value for translation of the viewport on x axis ;
  * @ys: a value for translation of the viewport on y axis ;
- * @gross: a value of zoom.
+ * @gross: a value of zoom ;
+ * @length0: a length reference to adimension all values, by default,
+ * this is the longest diagonal of the current box (without
+ * duplication) ;
+ * @up: the current up vector.
  * 
  * Values to define the position of the observer.
  */
@@ -81,13 +84,17 @@ struct OpenGLCamera_struct
 {
   /* Perspective. */
   double d_red;
-  double gr; /* equal to d_red / (d_red - 1.) */
   /* Orientation. */
   double theta, phi, omega;
   /* Position. */
   double xs, ys;
   /* Zoom. */
   double gross;
+  /* A length reference. */
+  double length0;
+
+  /* Up vector. */
+  double up[3];
 };
 /**
  * OpenGLCamera:
@@ -175,13 +182,26 @@ int openGLViewSet_gross(OpenGLView *view, float value);
  * Returns: TRUE if the signal OpenGLAskForReDraw should be emitted.
  */
 int openGLViewSet_persp(OpenGLView *view, float value);
+/**
+ * openGLViewSet_refLength:
+ * @view: a valid #OpenGLView object ;
+ * @length: a floating point value.
+ *
+ * Change the reference length. If @length is null or negative, the
+ * reference length is automatically computed using the box (without
+ * duplication).
+ *
+ * Returns: TRUE if openGLViewCompute_matrixAndView() should be called
+ * after.
+ */
+gboolean openGLViewSet_refLength(OpenGLView *view, float length);
 
 /**
  * OpenGLBox_struct:
- * @extens : not used ;
- * @dxxs2: the square value of the norm of the x vector of the box ;
- * @dyys2: the square value of the norm of the y vector of the box ;
- * @dzzs2: the square value of the norm of the z vector of the box ;
+ * @extens : the longest length in the box (with duplication) ;
+ * @dxxs2: the x translation in the cartesian basis set to center the box ;
+ * @dyys2: the y translation in the cartesian basis set to center the box ;
+ * @dzzs2: the Z translation in the cartesian basis set to center the box ;
  * @p1: the coordinates of the point (0,0,0) ;
  * @p2: the coordinates of the point (1,0,0) ;
  * @p3: the coordinates of the point (1,1,0) ;
@@ -189,7 +209,8 @@ int openGLViewSet_persp(OpenGLView *view, float value);
  * @p5: the coordinates of the point (0,0,1) ;
  * @p6: the coordinates of the point (1,0,1) ;
  * @p7: the coordinates of the point (1,1,1) ;
- * @p8: the coordinates of the point (0,1,1).
+ * @p8: the coordinates of the point (0,1,1) ;
+ * @extension: the extension of the box as periodic duplication.
  *
  * Values to describe the box where the render is done. These values are 
  * linked to a #VisuData object (the currentVisuData pointer) and valid as
@@ -198,10 +219,10 @@ int openGLViewSet_persp(OpenGLView *view, float value);
  */
 struct OpenGLBox_struct
 {
-  double extens; /* makes changes in modelize, project, and numberOfFacette */
-  
-  double dxxs2, dyys2, dzzs2;
-  double p1[3], p2[3], p3[3], p4[3], p5[3], p6[3], p7[3], p8[3];
+  float extens;
+  float dxxs2, dyys2, dzzs2;
+  float p1[3], p2[3], p3[3], p4[3], p5[3], p6[3], p7[3], p8[3];
+  float extension[3];
 };
 /**
  * OpenGLBox:
@@ -210,6 +231,41 @@ struct OpenGLBox_struct
  */
 typedef struct OpenGLBox_struct OpenGLBox;
 
+/**
+ * openGLViewSet_box:
+ * @view: an #OpenGLView object with an allocated @box attribute ;
+ * @basisSet: the basis-set in reduced form (see visu_data.h) ;
+ * @extension: the (x,y,z) extension in box coordinates.
+ *
+ * Compute the coordinates of the box vertex built on the basis-set axis.
+ * The size of the overall view is computed using the longest length in the
+ * box using the extension. If this extension is null, then the smallest box
+ * built on the basis-set is used, whereas if the extension is not null, then
+ * it means a double extension of the basis-set axis in each direction.
+ */
+void openGLViewSet_box(OpenGLView *view, float basisSet[6], float extension[3]);
+/**
+ * openGLViewGet_boxVertices:
+ * @view: an #OpenGLView object with an allocated @box attribute ;
+ * @vertices: a location to store the vertice coordinates ;
+ * @withExtension: a boolean.
+ *
+ * Return the vertices coordinates of the box of the @view, for the
+ * primitive cell if @withExtension is FALSE or for the current
+ * extension if TRUE.
+ */
+void openGLViewGet_boxVertices(OpenGLView *view, float vertices[8][3],
+			       gboolean withExtension);
+/**
+ * openGLViewGet_boxSpan:
+ * @view: an #OpenGLView object with an allocated @box attribute ;
+ * @span: a location to store two floats.
+ *
+ * Compute the two most far distance from origin in the box. The first
+ * is the negative one and the second, the positive one.
+ */
+void openGLViewGet_boxSpan(OpenGLView *view, float span[2]);
+
 /**
  * OpenGLWindow_struct:
  * @width : the width of the window ;
@@ -237,7 +293,7 @@ struct OpenGLWindow_struct
 typedef struct OpenGLWindow_struct OpenGLWindow;
 /**
  * OpenGLViewSet_windowSize:
- * @view: a valid #OpenGLView object (can be NULL);
+ * @view: a valid #OpenGLView object ;
  * @width: the new horizontal size ;
  * @height: the new vertical size.
  *
