@@ -105,7 +105,7 @@ void onSpinBoundsChanged(GObject *obj, gfloat val, gpointer data);
    for the atomic rendering method. */
 void panelElementAtomicInit_gtkPanel()
 {
-  panelElements_setInterfaceMethods(pointerOnRenderingAtomicMethod,
+  panelElements_setInterfaceMethods(renderingAtomicGet_static(),
 				    panelElementAtomicCallback_onElementChange,
 				    panelElementAtomicCreate_gtkInterface);
   currentListElement = (GList*)0;
@@ -115,7 +115,7 @@ void panelElementAtomicInit_gtkPanel()
    the atomic rendering method. */
 void panelElementAtomicInit_gtkMain()
 {
-  gtkMainClassSet_renderingSpecificMethods(pointerOnRenderingAtomicMethod,
+  gtkMainClassSet_renderingSpecificMethods(renderingAtomicGet_static(),
 					   (GtkMainSetFilesFunc)0);
 }
 
@@ -289,7 +289,7 @@ void onSpinBoundsChanged(GObject *obj _U_, gfloat mult, gpointer data _U_)
   int id;
   VisuData *dataObj;
 
-  if (getRenderingMethodInUse() != pointerOnRenderingAtomicMethod)
+  if (getRenderingMethodInUse() != renderingAtomicGet_static())
     return;
 
   DBG_fprintf(stderr, "Panel Atomic : catch the 'spinBoundsChanged' signal,"
@@ -303,7 +303,7 @@ void onSpinBoundsChanged(GObject *obj _U_, gfloat mult, gpointer data _U_)
       gtk_label_set_use_markup(GTK_LABEL(labelRadius), TRUE);
     }
 
-  dataObj = toolPanelGet_visuData(TOOL_PANEL(panelElements));
+  dataObj = toolPanelGet_visuData(TOOL_PANEL(PANEL_ELEMENTS));
   if (dataObj)
     for (i = 0; i < dataObj->ntype; i++)
       {
@@ -338,7 +338,7 @@ void shapeChanged(GtkComboBox *box, gpointer data _U_)
       if (renderingAtomicSet_shape(ele, shape))
 	{
 	  id = renderingAtomic_createShape
-	    (toolPanelGet_visuData(TOOL_PANEL(panelElements)), ele);
+	    (toolPanelGet_visuData(TOOL_PANEL(PANEL_ELEMENTS)), ele);
 	  ele->openGLIdentifier = id;
 	  refresh = TRUE;
 	}
@@ -360,7 +360,7 @@ void paramChanged(GtkSpinButton* button, gpointer data)
 
   g_return_if_fail(currentListElement);
 
-  dataObj = toolPanelGet_visuData(TOOL_PANEL(panelElements));
+  dataObj = toolPanelGet_visuData(TOOL_PANEL(PANEL_ELEMENTS));
 
   param = GPOINTER_TO_INT(data);
   value = gtk_spin_button_get_value(button);
