@@ -47,6 +47,7 @@
 
 #include <visu_gtk.h>
 #include <visu_elements.h>
+#include <renderingMethods/renderingAtomic.h>
 #include <renderingMethods/renderingSpin.h>
 #include <openGLFunctions/view.h>
 #include <coreTools/toolMatrix.h>
@@ -540,7 +541,7 @@ static gboolean gtkSpinCreate_fileChooser(VisuData *data, GtkWindow *parent)
   gtk_window_set_position(GTK_WINDOW(fileSelection), GTK_WIN_POS_CENTER_ON_PARENT);
   gtk_window_set_modal(GTK_WINDOW(fileSelection), TRUE);
 
-  tmpLst = renderingMethodGet_fileType(renderingSpinGet_static(),
+  tmpLst = renderingMethodGet_fileType(renderingAtomicGet_static(),
 				       FILE_KIND_POSITION);
   filterPos = gtk_file_filter_new ();
   while(tmpLst)
@@ -809,6 +810,9 @@ static void fileKindChangedForPosition(GtkToggleButton *button, gpointer data)
 			      (GtkFileFilter*)(tmpLst->data));
   param->fileKind = FILE_KIND_POSITION;
 
+  if (param->files[0])
+    gtk_file_chooser_select_filename(GTK_FILE_CHOOSER(param->fileChooserDialog),
+				     param->files[0]);
 }
 
 static void fileKindChangedForSpin(GtkToggleButton *button, gpointer data)
@@ -823,6 +827,10 @@ static void fileKindChangedForSpin(GtkToggleButton *button, gpointer data)
   gtk_file_chooser_set_filter(GTK_FILE_CHOOSER(param->fileChooserDialog),
 			      (GtkFileFilter*)(tmpLst->next->data));
   param->fileKind = FILE_KIND_SPIN;
+
+  if (param->files[1])
+    gtk_file_chooser_select_filename(GTK_FILE_CHOOSER(param->fileChooserDialog),
+				     param->files[1]);
 }
 
 /* Create the gtk widgets (a hbox with a spin with
@@ -1030,6 +1038,9 @@ void changeSomethingSpin(GList *eleList)
     g_list_free(currentListElement);
   currentListElement = g_list_copy(eleList);
 
+  DBG_fprintf(stderr, "Gtk Spin : give the element change to the atomic part.\n");
+  panelElementAtomicCallback_onElementChange(eleList);
+
   /* If the list has only one element, we continue
      and update the values on the widgets. */
   if (g_list_next(eleList))
@@ -1085,9 +1096,6 @@ void changeSomethingSpin(GList *eleList)
   g_signal_handler_unblock (lengthElipsoidSpin, element_callback_ids[8] );  
   g_signal_handler_unblock (useElementForElipsoid, element_callback_ids[9] );  
 
-  DBG_fprintf(stderr, "Gtk Spin : give the element change to the atomic part.\n");
-  panelElementAtomicCallback_onElementChange(eleList);
-
   need_redraw = 1;
 }
 
