@@ -376,7 +376,10 @@ static void scaleDistanceChanged(GtkSpinButton *spin, gpointer data _U_)
 
   DBG_fprintf(stderr, "Panel Box&axes: scale distance changed.\n");
   res = scaleSet_length(scale, (float)gtk_spin_button_get_value(GTK_SPIN_BUTTON(spin)));
-  scaleSet_legend(scale, (const gchar*)0);
+  if (*gtk_entry_get_text(GTK_ENTRY(entryScale)) == '\0')
+    scaleSet_legend(scale, (const gchar*)0);
+  else
+    scaleSet_legend(scale, gtk_entry_get_text(GTK_ENTRY(entryScale)));
 
   if (res)
     scaleRedraw();
