@@ -130,9 +130,9 @@ ToolPanel* panelBox_init()
   /* Create the callbacks of all the sensitive widgets. */
   g_signal_connect(G_OBJECT(panelBox), "page-entered",
 		   G_CALLBACK(onBoxEnter), (gpointer)0);
-  g_signal_connect(G_OBJECT(visu), "dataLoaded",
+  g_signal_connect(VISU_INSTANCE, "dataLoaded",
 		   G_CALLBACK(onVisuDataChanged), (gpointer)0);
-  g_signal_connect(G_OBJECT(visu), "dataReadyForRendering",
+  g_signal_connect(VISU_INSTANCE, "dataReadyForRendering",
 		   G_CALLBACK(onVisuDataReady), (gpointer)0);
 
   /* Private parameters. */
