@@ -1636,11 +1636,6 @@ static void panelBrowserBrowse_directory()
   int *nbPattern, i, nbFiles;
   GPatternSpec ***pattern;
   gchar nbFilesLabel[36];
-#if GLIB_MINOR_VERSION > 5
-  const gchar **charset;
-#else
-  const gchar *charset;
-#endif
 
   if (!currentBrowseredDirectory)
     return;
@@ -1703,14 +1698,7 @@ static void panelBrowserBrowse_directory()
   /* Add a timeout to show the progress bar if the scan is too long. */
   g_timeout_add(150, showProgressBar, (gpointer)nbFilesLabel);
 
-#if GLIB_MINOR_VERSION > 5
-  if (g_get_filename_charsets(&charset))
-#else
-  if (g_get_charset(&charset))
-#endif
-    len = g_utf8_strlen(commonBrowseredDirectory, -1);
-  else
-    len = strlen(commonBrowseredDirectory);
+  len = strlen(commonBrowseredDirectory);
   for (i = 0; currentBrowseredDirectory[i]; i++)
     {
       DBG_fprintf(stderr, "Panel browser : scanning directory '%s'.\n",
