@@ -736,9 +736,9 @@ static void createInteriorDataFile()
   g_signal_connect(G_OBJECT(checkbuttonData), "toggled",
 		   G_CALLBACK(useDataFileColor), (gpointer)0);
 
-  g_signal_connect(G_OBJECT(visu), "dataLoaded",
+  g_signal_connect(VISU_INSTANCE, "dataLoaded",
 		   G_CALLBACK(visuFileReset), (gpointer)0);
-  g_signal_connect(G_OBJECT(visu), "dataNew",
+  g_signal_connect(VISU_INSTANCE, "dataNew",
 		   G_CALLBACK(onDataNew), (gpointer)0);
   g_signal_connect(G_OBJECT(radioNormalized), "toggled",
 		   G_CALLBACK(onScaleTypeChange), (gpointer)dataFile_normalize);
