@@ -60,6 +60,13 @@
 #include "gtkAtomic.h"
 #include "gtkSpin.h"
 
+/**
+ * panelElements:
+ *
+ * A pointer on the #ToolPanel that host the elements chooser.
+ */
+static GtkWidget *panelElements;
+
 /* Functions used to initialise the
  * specific area in the panel of elements.
  */
@@ -68,7 +75,7 @@ static VisuToolsInitFunc listInitRendenringGtkPanelFunc[] = {
   panelElementSpinInit_gtkPanel,
   (VisuToolsInitFunc)0};
 
-GtkListStore *listStoreVisuElements;
+static GtkListStore *listStoreVisuElements;
 enum
   {
     COLUMN_NAME,  /* The label shown */
@@ -256,15 +263,15 @@ void createCallBacksElements()
   g_signal_connect(G_OBJECT(checkMasked), "toggled",
 		   G_CALLBACK(checkMaskedChanged), (gpointer)0);
   /* Connect the signal emitted by visu when a new file is loaded. */
-  g_signal_connect(G_OBJECT(visu), "dataReadyForRendering",
+  g_signal_connect(VISU_INSTANCE, "dataReadyForRendering",
 		   G_CALLBACK(refreshComboElements), (gpointer)0);
   /* Connect the signal emitted by visu when
      a new rendering method is selected. */
-  g_signal_connect(G_OBJECT(visu), "renderingChanged",
+  g_signal_connect(VISU_INSTANCE, "renderingChanged",
 		   G_CALLBACK(onRenderingMethodChanged), (gpointer)0);
   /* Connect the signal emitted by visu when
      a new rendering method is selected. */
-  g_signal_connect(G_OBJECT(visu), "resourcesLoaded",
+  g_signal_connect(VISU_INSTANCE, "resourcesLoaded",
 		   G_CALLBACK(resourcesChanged), (gpointer)0);
 }
 
@@ -489,8 +496,7 @@ void colorVisuElementChanged(ColorComboBox *colorWd _U_, Color *color,
   if (refresh)
     {
       DBG_fprintf(stderr, "Panel Element : color change, refresh.\n");
-      g_signal_emit (visu, VISU_GET_CLASS (visu)->OpenGLAskForReDraw_signal_id,
-		     0 , NULL);
+      g_idle_add(visuObjectRedraw, (gpointer)0);
     }
 }
 static void onColorChanged(ColorComboBox *colorComboBox, guint colorId,
@@ -550,8 +556,7 @@ static void onColorChanged(ColorComboBox *colorComboBox, guint colorId,
   if (refresh)
     {
       DBG_fprintf(stderr, "Panel Element : RGB change, refresh.\n");
-      g_signal_emit (visu, VISU_GET_CLASS (visu)->OpenGLAskForReDraw_signal_id,
-		     0 , NULL);
+      g_idle_add(visuObjectRedraw, (gpointer)0);
     }
   g_free(rgbVal);
 }
@@ -610,8 +615,7 @@ static void onMaterialChanged(ColorComboBox *colorComboBox, Material mat,
   if (refresh)
     {
       DBG_fprintf(stderr, "Panel Element : material change, refresh.\n");
-      g_signal_emit (visu, VISU_GET_CLASS (visu)->OpenGLAskForReDraw_signal_id,
-		     0 , NULL);
+      g_idle_add(visuObjectRedraw, (gpointer)0);
     }
   g_free(matVal);
 }
@@ -895,3 +899,8 @@ void getRenderingInterface(RenderingMethod *method,
       *create = interface->createInterface;
     }
 }
+
+GtkWidget* panelElementsGet_static()
+{
+  return panelElements;
+}
