@@ -50,13 +50,6 @@
 #include <visu_rendering.h>
 #include <extraGtkFunctions/gtk_toolPanelWidget.h>
 
-/**
- * panelElements:
- *
- * A pointer on the #ToolPanel that host the elements chooser.
- */
-GtkWidget *panelElements;
-
 /**
  * panelElementsInit:
  *
@@ -90,5 +83,9 @@ typedef void (*panelElements_changeFunc)(GList *eleList);
 void panelElements_setInterfaceMethods(RenderingMethod *method,
 				       panelElements_changeFunc change,
 				       createGtkWidgetFunc create);
+
+#define PANEL_ELEMENTS panelElementsGet_static()
+GtkWidget* panelElementsGet_static();
+
 #endif
 
