@@ -45,6 +45,7 @@
 #include "panelMethod.h"
 
 #include <visu_tools.h>
+#include <visu_object.h>
 #include <extraGtkFunctions/gtk_toolPanelWidget.h>
 
 #include "gtkSpin.h"
@@ -203,8 +204,8 @@ static void onMethodPanelEnter(ToolPanel *toolPanel _U_, gpointer data _U_)
   /* Set callbacks. */
   g_signal_connect(G_OBJECT(comboMethod), "changed",
          		   G_CALLBACK(comboInputMethodsChanged), (gpointer)0);
-  g_signal_connect(G_OBJECT(visu), "renderingChanged",
-		           G_CALLBACK(onRenderingChanged), (gpointer)1);
+  g_signal_connect(VISU_INSTANCE, "renderingChanged",
+		   G_CALLBACK(onRenderingChanged), (gpointer)1);
 
   /* Set the default values. */
   gtk_combo_box_set_active(GTK_COMBO_BOX(comboMethod), iterSelected);
