@@ -51,9 +51,11 @@
 #include <stdio.h>
 #include <string.h>
 #include <visu_gtk.h>
+#include <visu_basic.h>
 #include <extraFunctions/pot2surf.h>
 #include <extraFunctions/surfaces.h>
 #include <gtk_renderingWindowWidget.h>
+#include <renderingBackend/visu_windowInterface.h>
 
 static GtkWidget *convert_window;
 static gboolean convert_w_opened = FALSE;
@@ -984,7 +986,7 @@ void pot2surf_popup_help()
   GtkTextBuffer *text_buf;
   GtkWidget *text_view;
   GtkWidget *scrolled_window;
-  gchar *chemin = g_build_filename(v_sim_legal_dir, "pot2surf_help", NULL);
+  gchar *chemin = g_build_filename(V_SIM_LEGAL_DIR, "pot2surf_help", NULL);
 
   if(!g_file_get_contents(chemin, &text, &length, (GError**)0))
     {
@@ -1664,6 +1666,10 @@ gboolean pot2surf_build_surf_file(GtkWidget *button _U_, gpointer data)
   int n=0, i;
   const gchar *pot_file = gtk_entry_get_text(GTK_ENTRY(pot2surf_entry_source_pot_file));
   const gchar *surf_file = gtk_entry_get_text(GTK_ENTRY(pot2surf_entry_target_surf_file));
+  RenderingWindow *window;
+
+  window = RENDERING_WINDOW(visuRenderingWindowGet_current());
+  g_return_val_if_fail(window, FALSE);
 
   gtk_tree_model_foreach(GTK_TREE_MODEL(pot2surf_list_store), pot2surf_count_surf, &n);
   if(n == 0)
@@ -1719,7 +1725,7 @@ gboolean pot2surf_build_surf_file(GtkWidget *button _U_, gpointer data)
   if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data)))
     {
       if(panelIsosurfacesLoad_file(surf_file, 0,
-				   toolPanelGet_visuData(TOOL_PANEL(panelSurfaces)),
+				   renderingWindowGet_visuData(window),
 				   (OptionTable*)0) == 0)
 	{
 	  for(i=0; i<n; i++)
