@@ -448,7 +448,7 @@ void autoReloadRemoveTimeout(VisuData *data)
 gboolean automaticReload(gpointer data)
 {
   struct stat statBuf;
-  int res;
+  int res, iSet;
   char *file;
   time_t modTime;
   int kind, nbKind;
@@ -494,10 +494,10 @@ gboolean automaticReload(gpointer data)
   if (reloadNeeded)
     {
       DBG_fprintf(stderr, "Panel Config : automatic reloading in progress...\n");
+      iSet = visuDataGet_setId(dataObj);
       visuDataFree_population(dataObj);
       error = (GError*)0;
-      ok = visuBasicLoad_dataFromFile(dataObj, (FileFormat*)0,
-				      visuDataGet_setId(dataObj), &error);
+      ok = visuBasicLoad_dataFromFile(dataObj, (FileFormat*)0, iSet, &error);
       if (!ok)
 	{
 	  visuGtkRaise_warning(_("Automatic file reloading"), error->message,
