@@ -565,7 +565,7 @@ static void visu_data_init(VisuData *obj)
   obj->privateDt->attachedView     = (OpenGLView*)0;
 
   obj->privateDt->dataLoadedSignalId =
-    g_signal_connect_swapped(G_OBJECT(visu), "dataLoaded",
+    g_signal_connect_swapped(VISU_INSTANCE, "dataLoaded",
 			     G_CALLBACK(onDataLoadedSignal),
 			     (gpointer)obj);
 
@@ -580,7 +580,7 @@ static void visu_data_init(VisuData *obj)
   allObjects = g_list_append(allObjects, (gpointer)obj);
 
   DBG_fprintf(stderr, "Visu Data: emit the 'DataNew' signal.\n");
-  g_signal_emit(visu, VISU_GET_CLASS(visu)->dataNew_signal_id,
+  g_signal_emit(VISU_INSTANCE, VISU_GET_CLASS(VISU_INSTANCE)->dataNew_signal_id,
 		0 /* details */, G_OBJECT(obj), NULL);
   DBG_fprintf(stderr, "Visu Data: emission OK of the 'DataNew' signal.\n");
 }
@@ -595,7 +595,8 @@ static void visu_data_dispose(GObject* obj)
   if (VISU_DATA(obj)->privateDt->dispose_has_run)
     return;
 
-  g_signal_handler_disconnect(visu, VISU_DATA(obj)->privateDt->dataLoadedSignalId);
+  g_signal_handler_disconnect(VISU_INSTANCE,
+			      VISU_DATA(obj)->privateDt->dataLoadedSignalId);
 
   VISU_DATA(obj)->privateDt->dispose_has_run = TRUE;
 
@@ -1671,9 +1672,9 @@ static int* extendNodeList(VisuData *data, int coord, float valueTo)
 	      k <   (int)data->privateDt->extension[coord] + 1)
 	    continue;
 	  boxCoord[coord] += (float)k;
-	  if ((boxCoord[coord] >= -valueTo &&
+	  if ((boxCoord[coord] > -valueTo &&
 	       boxCoord[coord] <= -data->privateDt->extension[coord]) ||
-	      (boxCoord[coord] <= valueTo + 1.f &&
+	      (boxCoord[coord] < valueTo + 1.f &&
 	       boxCoord[coord] >= data->privateDt->extension[coord] + 1.f))
 	    {
 /* 	      DBG_fprintf(stderr, "Visu Data: replicating node %d, (%d) %g -> %g" */
@@ -2085,6 +2086,8 @@ void visuDataIter_start(VisuData *data, VisuDataIter *iter)
 }
 void visuDataIter_startNumber(VisuData *data, VisuDataIter *iter)
 {
+  guint i;
+
   g_return_if_fail(IS_VISU_DATA_TYPE(data) && iter && data == iter->data);
 
   iter->iElement = -1;
@@ -2093,7 +2096,14 @@ void visuDataIter_startNumber(VisuData *data, VisuDataIter *iter)
   if (data->ntype == 0)
     return;
 
-  iter->node = visuDataGet_nodeFromNumber(data, 0);
+  i = 0;
+  iter->node = (VisuNode*)0;
+  do
+    {
+      iter->node = visuDataGet_nodeFromNumber(data, i);
+      i += 1;
+    }
+  while (!iter->node && i < data->privateDt->nodeArray->nodeTableSize);
   if (!iter->node)
     return;
   iter->iElement = iter->node->posElement;
