@@ -74,7 +74,7 @@ int main (int argc, char *argv[])
 
 #ifdef ENABLE_NLS
   setlocale (LC_ALL, "");
-  bindtextdomain (GETTEXT_PACKAGE, v_sim_locale_dir);
+  bindtextdomain (GETTEXT_PACKAGE, V_SIM_LOCALE_DIR);
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
 #endif
