@@ -190,6 +190,9 @@ struct _VisuObjectClass
  */
 GType visu_get_type (void);
 
+#define VISU_INSTANCE visuObjectGet_static()
+GObject* visuObjectGet_static();
+
 G_END_DECLS
 
 #endif
