@@ -218,11 +218,11 @@ int initPairsModule()
 				   exportResourcesPairs);
 
 
-  g_signal_connect(G_OBJECT(visu), "dataReadyForRendering",
+  g_signal_connect(VISU_INSTANCE, "dataReadyForRendering",
 		   G_CALLBACK(onDataReady), (gpointer)0);
-  g_signal_connect(G_OBJECT(visu), "dataNew",
+  g_signal_connect(VISU_INSTANCE, "dataNew",
 		   G_CALLBACK(onNewData), (gpointer)0);
-  g_signal_connect(G_OBJECT(visu), "resourcesLoaded",
+  g_signal_connect(VISU_INSTANCE, "resourcesLoaded",
 		   G_CALLBACK(createPairsOnResources), (gpointer)0);
 
   DminDmax = g_hash_table_new_full(g_str_hash, g_str_equal, NULL, freePair);
