@@ -410,6 +410,7 @@ static void drawMarkDot(VisuData *data, VisuNode *node, PickMesureMarkType type)
 		   xyz[2] - view->box->dzzs2);
       gluSphere(obj, (double)eleSize * 1.25, 2 * nlat, 2 * nlat);
       glPopMatrix();
+      gluDeleteQuadric(obj);
       break;
     default:
       break;
@@ -569,10 +570,10 @@ static gboolean matchDotType(struct MarkInfo_struct *markInfo,
 /* 	  (markInfo->type > PICK_MESURE_END_MARK_DOT && */
 /* 	   markInfo->type < PICK_MESURE_END_MARK_LINK)); */
 /* } */
-static gboolean matchAny(struct MarkInfo_struct *markInfo, int nodeId,
+static gboolean matchFirst(struct MarkInfo_struct *markInfo, int nodeId,
 			 gpointer data _U_)
 {
-  return (markInfo->idNode1 == nodeId || markInfo->idNode2 == nodeId);
+  return (markInfo->idNode1 == nodeId);
 }
 static void addMarkDotToList(PickMesure *mesureData, int idNode,
 			     PickMesureMarkType type)
@@ -1306,7 +1307,7 @@ static void updateListOnPopulationChange(VisuData *dataObj, int *nodes,
   while (list)
     {
       for (i = 0; nodes[i] >= 0; i++)
-	if (matchAny((struct MarkInfo_struct*)list->data, nodes[i], (gpointer)0))
+	if (matchFirst((struct MarkInfo_struct*)list->data, nodes[i], (gpointer)0))
 	  rmList = g_list_append(rmList, list);
       list = g_list_next(list);
     }
