@@ -46,6 +46,7 @@
 
 #include "visu_plugins.h"
 #include "visu_tools.h"
+#include "visu_basic.h"
 
 /**
  * SECTION:visu_plugins
@@ -103,7 +104,7 @@ static gboolean visuPluginLoad_byPath(gchar* path)
       ptChar = g_strrstr(name, "-");
 #endif
 #if SYSTEM_X11 == 1
-      ptChar = g_strrstr(name, "."G_MODULE_SUFFIX);
+      ptChar = strchr(name, '.');
 #endif
       if (ptChar)
 	*ptChar = '\0';
@@ -193,9 +194,9 @@ gchar** visuPluginsGet_installedPlugins()
   int size;
 
   /* Try the install dir. */
-  lst1 = visuPluginsParseDir(v_sim_plugins_dir);
+  lst1 = visuPluginsParseDir(V_SIM_PLUGINS_DIR);
   /* Try the home dir. */
-  path = g_build_filename(v_sim_local_conf_dir, "plugins", NULL);
+  path = g_build_filename(V_SIM_LOCAL_CONF_DIR, "plugins", NULL);
   lst2 = visuPluginsParseDir(path);
   g_free(path);
 
