@@ -85,7 +85,8 @@ struct RenderingMethod_struct;
  */
 typedef struct RenderingMethod_struct RenderingMethod;
 
-GQuark VISU_ERROR_RENDERING;
+#define VISU_ERROR_RENDERING renderingMethodGet_quark()
+GQuark renderingMethodGet_quark();
 /**
  * RenderingErrorFlag:
  * @RENDERING_ERROR_METHOD: Error from the rendering method.
