@@ -93,14 +93,6 @@ G_BEGIN_DECLS
 #define V_SIM_VERSION       VERSION
 #define V_SIM_WEB_SITE      "http://inac.cea.fr/L_Sim/V_Sim"
 
-gchar *v_sim_data_dir;
-gchar *v_sim_legal_dir;
-gchar *v_sim_pixmaps_dir;
-gchar *v_sim_local_conf_dir;
-gchar *v_sim_old_local_conf_dir;
-gchar *v_sim_plugins_dir;
-gchar *v_sim_locale_dir;
-
 /**
  * MAX_LINE_LENGTH
  *
@@ -126,12 +118,6 @@ typedef void (*voidDataFunc)(gpointer data);
  */
 typedef void (*VisuToolsInitFunc)();
 
-
-
-/* All signal emit by visu are handled by this ogbject. */
-GObject *visu;
-
-
 /**
  * Property_struct:
  * @name: a pointer to a string, only used when DEBUG is on ;
